==> tentackle-swing-rdc-2.0.7-sources.jar: org/tentackle/swing/rdc/DefaultGuiProviderFactory.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.tentackle.swing.rdc;

import org.tentackle.common.Service;
import org.tentackle.common.ServiceFactory;
import org.tentackle.reflect.ClassMapper;
import org.tentackle.reflect.DefaultClassMapper;

/**
 * The default GUI provider factory.
 *
 * @author harald
 */
@Service(GuiProviderFactory.class)
public class DefaultGuiProviderFactory extends AbstractGuiProviderFactory {


  private final ClassMapper guiClassMapper;


  public DefaultGuiProviderFactory() {
    guiClassMapper = new DefaultClassMapper("Swing GUI-provider", ServiceFactory.getServiceFinder().createNameMap(GuiProvider.class.getName()), null);
  }


  @Override
  public ClassMapper getGuiMapper() {
    return guiClassMapper;
  }

}

==> tentackle-swing-rdc-8.2.8.0-sources.jar: org/tentackle/swing/rdc/DefaultGuiProviderFactory.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.tentackle.swing.rdc;

import org.tentackle.common.Constants;
import org.tentackle.common.Service;
import org.tentackle.common.ServiceFactory;
import org.tentackle.reflect.ClassMapper;
import org.tentackle.reflect.DefaultClassMapper;

/**
 * The default GUI provider factory.
 *
 * @author harald
 */
@Service(GuiProviderFactory.class)
public class DefaultGuiProviderFactory extends AbstractGuiProviderFactory {


  private final ClassMapper guiClassMapper;


  public DefaultGuiProviderFactory() {
    guiClassMapper = new DefaultClassMapper(
            "Swing GUI-provider",
            ServiceFactory.getClassLoader(Constants.MAPPED_SERVICE_PATH, GuiProvider.class.getName()),
            ServiceFactory.getServiceFinder().createNameMap(GuiProvider.class.getName()), null);
  }


  @Override
  public ClassMapper getGuiMapper() {
    return guiClassMapper;
  }

}
